User_Agent = "Mozilla/5.0 (Linux; Android 9; V1916A Build/PQ3B.190801.002; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/91.0.4472.114 Mobile Safari/537.36 V1_AND_SQ_8.9.83_4680_YYB_D PA QQ/8.9.83.12605 NetType/WIFI WebP/0.4.1 AppId/537178647 Pixel/540 StatusBarHeight/37 SimpleUISwitch/0 QQTheme/1103 StudyMode/0 CurrentMode/0 CurrentFontScale/1.0 GlobalDensityScale/1.0 AllowLandscape/false InMagicWin/0"