# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oidb_0x88d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10oidb_0x88d.proto\x12\x10im.oidb.cmd0x88d\"O\n\tGroupInfo\x12\x13\n\x0bgroup_owner\x18\x01 \x01(\x04\x12\x17\n\x0fgroup_class_ext\x18\x07 \x01(\r\x12\x14\n\x0cgroup_answer\x18\x18 \x01(\t\"v\n\x0cReqGroupInfo\x12\x12\n\ngroup_code\x18\x01 \x01(\x04\x12\x30\n\x0bstgroupinfo\x18\x02 \x01(\x0b\x32\x1b.im.oidb.cmd0x88d.GroupInfo\x12 \n\x18last_get_group_name_time\x18\x03 \x01(\r\"i\n\x07ReqBody\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x34\n\x0creqgroupinfo\x18\x02 \x03(\x0b\x32\x1e.im.oidb.cmd0x88d.ReqGroupInfo\x12\x19\n\x11pc_client_version\x18\x03 \x01(\r\"d\n\x0cRspGroupInfo\x12\x12\n\ngroup_code\x18\x01 \x01(\x04\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\x30\n\x0bstgroupinfo\x18\x03 \x01(\x0b\x32\x1b.im.oidb.cmd0x88d.GroupInfo\"O\n\x07RspBody\x12\x31\n\tgroupinfo\x18\x01 \x03(\x0b\x32\x1e.im.oidb.cmd0x88d.RspGroupInfo\x12\x11\n\terrorinfo\x18\x02 \x01(\x0c')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oidb_0x88d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GROUPINFO']._serialized_start=38
  _globals['_GROUPINFO']._serialized_end=117
  _globals['_REQGROUPINFO']._serialized_start=119
  _globals['_REQGROUPINFO']._serialized_end=237
  _globals['_REQBODY']._serialized_start=239
  _globals['_REQBODY']._serialized_end=344
  _globals['_RSPGROUPINFO']._serialized_start=346
  _globals['_RSPGROUPINFO']._serialized_end=446
  _globals['_RSPBODY']._serialized_start=448
  _globals['_RSPBODY']._serialized_end=527
# @@protoc_insertion_point(module_scope)
