# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/scanlogin/scanlogin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+AndroidQQ/im/oidb/scanlogin/scanlogin.proto\"3\n\x0cScanLoginReq\x12\x14\n\x0cservice_type\x18\x02 \x01(\x05\x12\r\n\x05token\x18\x03 \x01(\x0c\"N\n\x0cScanLoginRsp\x12\x0e\n\x06\x66ield1\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ield2\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ield3\x18\x03 \x01(\x05\x12\x0e\n\x06\x66ield4\x18\x04 \x01(\x0c')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.scanlogin.scanlogin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCANLOGINREQ']._serialized_start=47
  _globals['_SCANLOGINREQ']._serialized_end=98
  _globals['_SCANLOGINRSP']._serialized_start=100
  _globals['_SCANLOGINRSP']._serialized_end=178
# @@protoc_insertion_point(module_scope)
