# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/cmd0x922/cmd0x922.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from AndroidQQ.im.oidb.cmd0x922 import PushInfo_pb2 as AndroidQQ_dot_im_dot_oidb_dot_cmd0x922_dot_PushInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)AndroidQQ/im/oidb/cmd0x922/cmd0x922.proto\x12\x10im.oidb.cmd0x922\x1a)AndroidQQ/im/oidb/cmd0x922/PushInfo.proto\"\x1c\n\x07ReqBody\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\"\x80\x01\n\x07RspBody\x12\x18\n\x10need_update_flag\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x31\n\rmsg_push_info\x18\x03 \x01(\x0b\x32\x1a.im.oidb.cmd0x922.PushInfo\x12\x15\n\rnext_req_time\x18\x04 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.cmd0x922.cmd0x922_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_REQBODY']._serialized_start=106
  _globals['_REQBODY']._serialized_end=134
  _globals['_RSPBODY']._serialized_start=137
  _globals['_RSPBODY']._serialized_end=265
# @@protoc_insertion_point(module_scope)
