# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: IM_r.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nIM_r.proto\"\x95\x02\n\x0eOidbSvc0x88d1r\x12\n\n\x02\x66\x31\x18\x01 \x01(\x05\x12\n\n\x02\x66\x32\x18\x02 \x01(\x05\x12\n\n\x02\x66\x33\x18\x03 \x01(\x05\x12\"\n\x02\x66\x34\x18\x04 \x01(\x0b\x32\x16.OidbSvc0x88d1r.Field4\x1a\xba\x01\n\x06\x46ield4\x12*\n\x02\x66\x31\x18\x01 \x01(\x0b\x32\x1e.OidbSvc0x88d1r.Field4.Field41\x1a\x83\x01\n\x07\x46ield41\x12\r\n\x05group\x18\x01 \x01(\x05\x12\n\n\x02\x66\x32\x18\x02 \x01(\x05\x12\x33\n\x02\x66\x33\x18\x03 \x01(\x0b\x32\'.OidbSvc0x88d1r.Field4.Field41.Field413\x1a(\n\x08\x46ield413\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\x0e\n\x06prompt\x18\x18 \x01(\t\"\xbf\x03\n\rOidbSvc0xeb8r\x12\x0b\n\x03src\x18\x01 \x01(\x05\x12\x11\n\tproto_ver\x18\x02 \x01(\x05\x12\x0f\n\x07\x66ield_3\x18\x03 \x01(\x05\x12(\n\x08Rsp_Body\x18\x04 \x01(\x0b\x32\x16.OidbSvc0xeb8r.RspBody\x1a\xd2\x02\n\x07RspBody\x12\x14\n\x0c\x63heck_result\x18\x01 \x01(\x05\x12\x34\n\nphone_info\x18\x02 \x03(\x0b\x32 .OidbSvc0xeb8r.RspBody.PhoneInfo\x12\x18\n\x10mibao_change_url\x18\x04 \x01(\t\x12\x18\n\x10mibao_verify_url\x18\x05 \x01(\t\x12\x1b\n\x13verify_premibao_url\x18\x06 \x01(\t\x12\x15\n\rhori_bar_tips\x18\x07 \x01(\t\x12\x14\n\x0cred_dot_tips\x18\x08 \x01(\t\x12\x0e\n\x06is_IOT\x18\t \x01(\x08\x1am\n\tPhoneInfo\x12\x12\n\nphone_type\x18\x01 \x01(\x05\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\x14\n\x0cphone_status\x18\x04 \x01(\x05\x12\x11\n\tvas_phone\x18\x05 \x01(\x0c\"\xf2\x02\n\rOidbSvc0xc05r\x12\x0b\n\x03src\x18\x01 \x01(\x05\x12\x11\n\tproto_ver\x18\x02 \x01(\x05\x12\x0f\n\x07\x66ield_3\x18\x03 \x01(\x05\x12(\n\x08Rsp_Body\x18\x04 \x01(\x0b\x32\x16.OidbSvc0xc05r.RspBody\x1a\xba\x01\n\nAppListRsp\x12\x13\n\x0btotal_count\x18\x01 \x01(\x05\x12\x35\n\tapp_infos\x18\x02 \x03(\x0b\x32\".OidbSvc0xc05r.AppListRsp.appinfos\x12\r\n\x05limit\x18\x03 \x01(\x05\x1aQ\n\x08\x61ppinfos\x12\r\n\x05\x61ppid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04logo\x18\t \x01(\t\x12\x0c\n\x04time\x18\x1a \x01(\x05\x1aI\n\x07RspBody\x12\x0f\n\x07wording\x18\x01 \x01(\t\x12-\n\nAppListRsp\x18\x0b \x01(\x0b\x32\x19.OidbSvc0xc05r.AppListRspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IM_r_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OIDBSVC0X88D1R']._serialized_start=15
  _globals['_OIDBSVC0X88D1R']._serialized_end=292
  _globals['_OIDBSVC0X88D1R_FIELD4']._serialized_start=106
  _globals['_OIDBSVC0X88D1R_FIELD4']._serialized_end=292
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41']._serialized_start=161
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41']._serialized_end=292
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41_FIELD413']._serialized_start=252
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41_FIELD413']._serialized_end=292
  _globals['_OIDBSVC0XEB8R']._serialized_start=295
  _globals['_OIDBSVC0XEB8R']._serialized_end=742
  _globals['_OIDBSVC0XEB8R_RSPBODY']._serialized_start=404
  _globals['_OIDBSVC0XEB8R_RSPBODY']._serialized_end=742
  _globals['_OIDBSVC0XEB8R_RSPBODY_PHONEINFO']._serialized_start=633
  _globals['_OIDBSVC0XEB8R_RSPBODY_PHONEINFO']._serialized_end=742
  _globals['_OIDBSVC0XC05R']._serialized_start=745
  _globals['_OIDBSVC0XC05R']._serialized_end=1115
  _globals['_OIDBSVC0XC05R_APPLISTRSP']._serialized_start=854
  _globals['_OIDBSVC0XC05R_APPLISTRSP']._serialized_end=1040
  _globals['_OIDBSVC0XC05R_APPLISTRSP_APPINFOS']._serialized_start=959
  _globals['_OIDBSVC0XC05R_APPLISTRSP_APPINFOS']._serialized_end=1040
  _globals['_OIDBSVC0XC05R_RSPBODY']._serialized_start=1042
  _globals['_OIDBSVC0XC05R_RSPBODY']._serialized_end=1115
# @@protoc_insertion_point(module_scope)
