# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cmd0xeb8.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63md0xeb8.proto\x12\x18tencent.im.oidb.cmd0xeb8\"m\n\tPhoneInfo\x12\x12\n\nphone_type\x18\x01 \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\x14\n\x0cphone_status\x18\x04 \x01(\r\x12\x11\n\tvas_phone\x18\x05 \x01(\x0c\")\n\x07ReqBody\x12\x0b\n\x03src\x18\x01 \x01(\r\x12\x11\n\tproto_ver\x18\x02 \x01(\r\"\xfd\x01\n\x07RspBody\x12\x14\n\x0c\x63heck_result\x18\x01 \x01(\r\x12\x37\n\nphone_info\x18\x02 \x03(\x0b\x32#.tencent.im.oidb.cmd0xeb8.PhoneInfo\x12\x15\n\rmibao_set_url\x18\x03 \x01(\t\x12\x18\n\x10mibao_change_url\x18\x04 \x01(\t\x12\x18\n\x10mibao_verify_url\x18\x05 \x01(\t\x12\x1b\n\x13verify_premibao_url\x18\x06 \x01(\t\x12\x15\n\rhori_bar_tips\x18\x07 \x01(\t\x12\x14\n\x0cred_dot_tips\x18\x08 \x01(\t\x12\x0e\n\x06is_IOT\x18\t \x01(\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cmd0xeb8_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PHONEINFO']._serialized_start=44
  _globals['_PHONEINFO']._serialized_end=153
  _globals['_REQBODY']._serialized_start=155
  _globals['_REQBODY']._serialized_end=196
  _globals['_RSPBODY']._serialized_start=199
  _globals['_RSPBODY']._serialized_end=452
# @@protoc_insertion_point(module_scope)
