# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oidb_sso.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eoidb_sso.proto\x12\x18tencent.im.oidb.oidb_sso\"&\n\x08MetaData\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbf\x01\n\nOIDBSSOPkg\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\r\x12\x14\n\x0cservice_type\x18\x02 \x01(\r\x12\x0e\n\x06result\x18\x03 \x01(\r\x12\x12\n\nbodybuffer\x18\x04 \x01(\x0c\x12\x11\n\terror_msg\x18\x05 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x06 \x01(\t\x12;\n\x0ftrpc_trans_info\x18\x07 \x03(\x0b\x32\".tencent.im.oidb.oidb_sso.MetaData')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oidb_sso_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_METADATA']._serialized_start=44
  _globals['_METADATA']._serialized_end=82
  _globals['_OIDBSSOPKG']._serialized_start=85
  _globals['_OIDBSSOPKG']._serialized_end=276
# @@protoc_insertion_point(module_scope)
