# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/oidb_0xc05/oidb_0xc05.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from AndroidQQ.im.oidb.qqconnect import qqconnect_pb2 as AndroidQQ_dot_im_dot_oidb_dot_qqconnect_dot_qqconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-AndroidQQ/im/oidb/oidb_0xc05/oidb_0xc05.proto\x12\x0ftencent.im.oidb\x1a+AndroidQQ/im/oidb/qqconnect/qqconnect.proto\"1\n\x11GetAuthAppListReq\x12\r\n\x05start\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"g\n\x11GetAuthAppListRsp\x12\x13\n\x0btotal_count\x18\x01 \x01(\r\x12*\n\x08\x61ppinfos\x18\x02 \x03(\x0b\x32\x18.tencent.im.oidb.Appinfo\x12\x11\n\tcur_index\x18\x03 \x01(\r\"3\n\x13GetCreateAppListReq\x12\r\n\x05start\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"*\n\x13GetCreateAppListRsp\x12\x13\n\x0btotal_count\x18\x01 \x01(\r\"\x93\x01\n\x07ReqBody\x12\x45\n\x17get_create_app_list_req\x18\n \x01(\x0b\x32$.tencent.im.oidb.GetCreateAppListReq\x12\x41\n\x15get_auth_app_list_req\x18\x0b \x01(\x0b\x32\".tencent.im.oidb.GetAuthAppListReq\"\xa4\x01\n\x07RspBody\x12\x0f\n\x07wording\x18\x01 \x01(\t\x12\x45\n\x17get_create_app_list_rsp\x18\n \x01(\x0b\x32$.tencent.im.oidb.GetCreateAppListRsp\x12\x41\n\x15get_auth_app_list_rsp\x18\x0b \x01(\x0b\x32\".tencent.im.oidb.GetAuthAppListRsp')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.oidb_0xc05.oidb_0xc05_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETAUTHAPPLISTREQ']._serialized_start=111
  _globals['_GETAUTHAPPLISTREQ']._serialized_end=160
  _globals['_GETAUTHAPPLISTRSP']._serialized_start=162
  _globals['_GETAUTHAPPLISTRSP']._serialized_end=265
  _globals['_GETCREATEAPPLISTREQ']._serialized_start=267
  _globals['_GETCREATEAPPLISTREQ']._serialized_end=318
  _globals['_GETCREATEAPPLISTRSP']._serialized_start=320
  _globals['_GETCREATEAPPLISTRSP']._serialized_end=362
  _globals['_REQBODY']._serialized_start=365
  _globals['_REQBODY']._serialized_end=512
  _globals['_RSPBODY']._serialized_start=515
  _globals['_RSPBODY']._serialized_end=679
# @@protoc_insertion_point(module_scope)
