# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/qqconnect/qqconnect.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+AndroidQQ/im/oidb/qqconnect/qqconnect.proto\x12\x0ftencent.im.oidb\"\xbf\x01\n\x12TencentDocsAppinfo\x12\x12\n\nopen_types\x18\x01 \x01(\t\x12\x0c\n\x04opts\x18\x02 \x01(\t\x12\x0b\n\x03\x65js\x18\x03 \x01(\t\x12\x19\n\x11\x63\x61llback_url_test\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61llback_url\x18\x05 \x01(\t\x12\x0e\n\x06\x64omain\x18\x06 \x01(\t\x12\x19\n\x11userinfo_callback\x18\x07 \x01(\t\x12\x1e\n\x16userinfo_callback_test\x18\x08 \x01(\t\"\xc6\x04\n\x07\x41ppinfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x61pp_type\x18\x02 \x01(\r\x12\x10\n\x08platform\x18\x03 \x01(\r\x12\x10\n\x08\x61pp_name\x18\x04 \x01(\t\x12\x0f\n\x07\x61pp_key\x18\x05 \x01(\t\x12\x11\n\tapp_state\x18\x06 \x01(\r\x12\x19\n\x11iphone_url_scheme\x18\x07 \x01(\t\x12\x19\n\x11\x61ndroid_pack_name\x18\x08 \x01(\t\x12\x10\n\x08icon_url\x18\t \x01(\t\x12\x12\n\nsource_url\x18\n \x01(\t\x12\x16\n\x0eicon_small_url\x18\x0b \x01(\t\x12\x17\n\x0ficon_middle_url\x18\x0c \x01(\t\x12\x41\n\x14tencent_docs_appinfo\x18\r \x03(\x0b\x32#.tencent.im.oidb.TencentDocsAppinfo\x12\x15\n\rdeveloper_uin\x18\x15 \x01(\x04\x12\x11\n\tapp_class\x18\x16 \x01(\r\x12\x14\n\x0c\x61pp_subclass\x18\x17 \x01(\r\x12\x0e\n\x06remark\x18\x18 \x01(\t\x12\x15\n\ricon_mini_url\x18\x19 \x01(\t\x12\x11\n\tauth_time\x18\x1a \x01(\x04\x12\x0f\n\x07\x61pp_url\x18\x1b \x01(\t\x12\x16\n\x0euniversal_link\x18\x1c \x01(\t\x12\x19\n\x11qqconnect_feature\x18\x1d \x01(\r\x12\x13\n\x0bis_hatchery\x18\x1e \x01(\x05\x12\x1b\n\x13\x65\x64it_universal_link\x18  \x01(\t\x12\x12\n\ncompany_id\x18! \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.qqconnect.qqconnect_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TENCENTDOCSAPPINFO']._serialized_start=65
  _globals['_TENCENTDOCSAPPINFO']._serialized_end=256
  _globals['_APPINFO']._serialized_start=259
  _globals['_APPINFO']._serialized_end=841
# @@protoc_insertion_point(module_scope)
