# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/cmd0x922/PushInfo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)AndroidQQ/im/oidb/cmd0x922/PushInfo.proto\x12\x10im.oidb.cmd0x922\"\x94\x01\n\x08PushInfo\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x11\n\tred_point\x18\x02 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\r\x12\x0e\n\x06prompt\x18\x04 \x01(\x0c\x12\x0b\n\x03url\x18\x05 \x01(\x0c\x12\x10\n\x08icon_url\x18\x06 \x01(\x0c\x12\x18\n\x10lst_checkin_time\x18\x07 \x01(\r\x12\x11\n\topen_func\x18\x08 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.cmd0x922.PushInfo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PUSHINFO']._serialized_start=64
  _globals['_PUSHINFO']._serialized_end=212
# @@protoc_insertion_point(module_scope)
